@@ -174,7 +174,7 @@ def get_border_dict(labels,states=None,radius=10,vdist=None,return_nnindex=True,
                 border_pts_i,n_i,c_i=get_surface_points(msk,return_normals=True,return_curvature=True)
             else:
                 n_i=np.zeros((indi.size,border_pts.shape[1]))
-                c_i=n_i.copy()
+                c_i=np.zeros(indi.size)
             n[indi]=n_i
             c[indi]=c_i
         border_dict['n']=n
@@ -1584,7 +1584,7 @@ def get_border_properties(cell_labels,surfaces=None,cell_states=None,surface_sta
                 indcell=np.where(border_dict['index']==cellid)[0]
                 border_pts=border_dict['pts'][indcell,:]
                 indcell_next=np.where(np.isin(border_dict_next['index'],lin_next[cellid]))[0]
-                if indcell_next.size>1:
+                if indcell.size>1 and indcell_next.size>1:
                     border_pts_next=border_dict_next['pts'][indcell_next,:]
                     inds_ot,dx_ot=get_ot_dx(border_pts,border_pts_next,return_dx=True,return_cost=False)
                     border_dx_next[indcell,:]=-dx_ot
@@ -1630,7 +1630,7 @@ def get_border_properties(cell_labels,surfaces=None,cell_states=None,surface_sta
                 indcell=np.where(border_dict['index']==cellid)[0]
                 border_pts=border_dict['pts'][indcell,:]
                 indcell_prev=np.where(np.isin(border_dict_prev['index'],lin_prev[cellid]))[0]
-                if indcell_prev.size>0:
+                if indcell.size>1 and indcell_prev.size>1:
                     border_pts_prev=border_dict_prev['pts'][indcell_prev,:]
                     inds_ot,dx_ot=get_ot_dx(border_pts,border_pts_prev,return_dx=True,return_cost=False)
                     border_dx_prev[indcell,:]=-dx_ot
